[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
40/53: gnu: emacs-nodejs-repl: Improve package style.
From: |
guix-commits |
Subject: |
40/53: gnu: emacs-nodejs-repl: Improve package style. |
Date: |
Thu, 22 Feb 2024 10:19:03 -0500 (EST) |
ngz pushed a commit to branch master
in repository guix.
commit eefd12d4046b03917433d1efadc339f862684833
Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
AuthorDate: Thu Feb 22 14:48:50 2024 +0100
gnu: emacs-nodejs-repl: Improve package style.
* gnu/packages/emacs-xyz.scm (emacs-nodejs-repl)[arguments]: Use
G-expressions. Use SEARCH-INPUT-FILES. Remove trailing #T. Remove
unnecessary call to MAKE-FILE-WRITABLE.
Change-Id: I9da1e24566359970cbf24129acb67f9f0610fb80
---
gnu/packages/emacs-xyz.scm | 43 ++++++++++++++++++++-----------------------
1 file changed, 20 insertions(+), 23 deletions(-)
diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index f8cf5bf986..2bab584478 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -14146,29 +14146,26 @@ an Emacs buffer.")
(native-inputs
(list emacs-ert-expectations))
(arguments
- `(#:phases
- (modify-phases %standard-phases
- (add-after 'unpack 'set-shell
- ;; Setting the SHELL environment variable is required for the tests
- ;; to find sh.
- (lambda _
- (setenv "SHELL" (which "sh"))
- #t))
- (add-after 'unpack 'configure
- (lambda* (#:key inputs outputs #:allow-other-keys)
- (let ((node (assoc-ref inputs "node")))
- ;; Specify the absolute file names of the various
- ;; programs so that everything works out-of-the-box.
- (make-file-writable "nodejs-repl.el")
- (emacs-substitute-variables
- "nodejs-repl.el"
- ("nodejs-repl-command"
- (string-append node "/bin/node")))))))
- #:tests? #t
- #:test-command '("emacs" "-Q" "--batch"
- "-L" "."
- "-l" "test/test.el"
- "-f" "ert-run-tests-batch-and-exit")))
+ (list
+ #:phases
+ #~(modify-phases %standard-phases
+ (add-after 'unpack 'set-shell
+ ;; Setting the SHELL environment variable is required for the tests
+ ;; to find sh.
+ (lambda _
+ (setenv "SHELL" (which "sh"))))
+ (add-after 'unpack 'configure
+ (lambda* (#:key inputs #:allow-other-keys)
+ (let ((node (search-input-file inputs "/bin/node")))
+ ;; Specify the absolute file names of the various
+ ;; programs so that everything works out-of-the-box.
+ (emacs-substitute-variables "nodejs-repl.el"
+ ("nodejs-repl-command" node))))))
+ #:tests? #t
+ #:test-command #~(list "emacs" "-Q" "--batch"
+ "-L" "."
+ "-l" "test/test.el"
+ "-f" "ert-run-tests-batch-and-exit")))
(home-page "https://github.com/abicky/nodejs-repl.el")
(synopsis "Node.js REPL inside Emacs")
(description
- 27/53: gnu: emacs-elpher: Update to 3.5.1., (continued)
- 27/53: gnu: emacs-elpher: Update to 3.5.1., guix-commits, 2024/02/22
- 28/53: gnu: emacs-ement: Update to 0.14., guix-commits, 2024/02/22
- 31/53: gnu: emacs-flymake-mypy: Update to 0.3.1., guix-commits, 2024/02/22
- 32/53: gnu: emacs-goggles: Update to 0.4., guix-commits, 2024/02/22
- 33/53: gnu: emacs-gptel: Update to 0.7.0., guix-commits, 2024/02/22
- 35/53: gnu: emacs-log4e: Update to 0.4.1., guix-commits, 2024/02/22
- 36/53: gnu: emacs-magit-todos: Update to 1.7.1., guix-commits, 2024/02/22
- 37/53: gnu: emacs-mastodon: Update to 1.0.14., guix-commits, 2024/02/22
- 38/53: gnu: emacs-meow: Update to 1.4.5., guix-commits, 2024/02/22
- 39/53: gnu: emacs-nodejs-repl: Update to 0.2.5., guix-commits, 2024/02/22
- 40/53: gnu: emacs-nodejs-repl: Improve package style.,
guix-commits <=
- 44/53: gnu: emacs-parent-mode: Run tests., guix-commits, 2024/02/22
- 46/53: gnu: emacs-ox-tufte: Update to 4.0.4., guix-commits, 2024/02/22
- 52/53: gnu: emacs-visual-fill-column: Update to 2.5.2., guix-commits, 2024/02/22
- 48/53: gnu: emacs-saveplace-pdf-view: Update to 1.0.6., guix-commits, 2024/02/22
- 51/53: gnu: emacs-vertico: Update to 1.7., guix-commits, 2024/02/22
- 42/53: gnu: emacs-osm: Update to 1.3., guix-commits, 2024/02/22
- 41/53: gnu: emacs-org: Update to 9.6.19., guix-commits, 2024/02/22
- 43/53: gnu: emacs-parent-mode: Update to 2.3.1., guix-commits, 2024/02/22
- 45/53: gnu: emacs-org-fc: Update to 0.5.1., guix-commits, 2024/02/22
- 47/53: gnu: emacs-pg: Update to 0.28., guix-commits, 2024/02/22